Learn R Programming

AgeBandDecomposition (version 2.0.0)

inTRW: AgeBandDecomposition test data

Description

A tiny test dataset including example, the basic reference for AgeBandDecomposition package.

A list of two test datasets derived from TRW_readExcel function. The first list-object is a tibble that can be used as the argument of stdTRW function.

Usage

inTRW

inTRW

Arguments

Format

A tibble with 85 rows and 16 variables, as derived from the Excel file.

A list of two tibbles